16.143. cdist-type__service(7) — cdist 6.9.4 documentation

# 16.143. cdist-type__service(7)

## 16.143.1. NAME

cdist-type__service - Run action on a system service

## 16.143.2. DESCRIPTION

This type allows you to run an action against a system service.

## 16.143.3. REQUIRED PARAMETERS

action

  Arbitrary parameter passed as action. Usually 'start', 'stop', 'reload' or 'restart'.

## 16.143.4. OPTIONAL PARAMETERS

None.

## 16.143.5. BOOLEAN PARAMETERS

None.

## 16.143.6. EXAMPLES

    # Restart nginx service.
    __service nginx --action restart

    # Stop postfix service.
    __service postfix --action stop

## 16.143.7. AUTHORS

Timothée Floure <timothee.floure@ungleich.ch>

## 16.143.8. COPYING

Copyright (C) 2019 Timothée Floure. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.